# Reporting Security Issues

The maintainers of this package take security bugs seriously. We appreciate your efforts to responsibly
disclose your findings, and will make every effort to acknowledge your contributions.

To report a security issue, please use the GitHub Security
Advisory ["Report a Vulnerability"](https://github.com/{{ github_package_group|replace("_", "-") }}/{{ github_package_name|replace("_", "-") }}/security/advisories/new) 
tab.

The maintainers will send a response indicating the next steps in handling your report. After the initial reply to
your report, the security team will keep you informed of the progress towards a fix and full announcement, and may ask
for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining the module.

## Source

This file was inspired by: https://github.com/electron/electron/blob/main/SECURITY.md
